import netgen.gui
from ngsolve import *
import matplotlib.pyplot as plt
from netgen.csg import *
import numpy as  np
r1 = 0.2;
r2 = 0.5;

meshsize = 0.05;
geo = CSGeometry()

sphere1 = Sphere(Pnt(0,0,0),r1)
sphere1.mat("water")
geo.Add(sphere1)


sphere2 = Sphere(Pnt(0,0,0),r2)
sphere2.mat("air")
geo.Add(sphere2-sphere1)

mesh = Mesh(geo.GenerateMesh(maxh=meshsize))
#mesh.Export("export.msh","Gmsh2 Format")

waveno = { "water" : 30., "air" : 20.}
kv = [ waveno[mat] for mat in mesh.GetMaterials() ]
#k = DomainConstantCF (kv)
k = CoefficientFunction ([kv])

fes = H1(mesh, order=1, complex=True)
u = fes.TrialFunction()
v = fes.TestFunction()


f = LinearForm(fes)
f += SymbolicLFI(exp(1j*k*x)*v)


a = BilinearForm(fes)
a += SymbolicBFI(u*v)

a.Assemble()
f.Assemble()

gfu = GridFunction(fes)
gfu.vec.data = a.mat.Inverse() * f.vec

Draw(gfu)

# VTKOutput object
#vtk = VTKOutput(ma=mesh,
                #coefs=[gfu],
                #names = ["u"],
                #filename="result",
                #subdivision=3)
## Exporting the results:
#vtk.Do() ## this live gives RuntimeError: BaseVector<Complex>::GetIndirect<double> called
